ArchivedBTreeSet

Struct ArchivedBTreeSet 

pub struct ArchivedBTreeSet<K, const E: usize = 5>(/* private fields */);
An archived BTreeSet. This is a wrapper around a B-tree map with the same key and a value of ().

Implementations

Source

impl<K, const E: usize> ArchivedBTreeSet<K, E>

pub fn iter(&self) -> Iter<'_, K, E>

Returns an iterator over the items of the archived B-tree set.

Source

impl<K, const E: usize> ArchivedBTreeSet<K, E>

pub fn contains_key<Q: Ord + ?Sized>(&self, key: &Q) -> bool
where K: Borrow<Q> + Ord,

Returns true if the set contains a value for the specified key.

The key may be any borrowed form of the set’s key type, but the ordering on the borrowed form must match the ordering on the key type.

pub fn get<Q: Ord + ?Sized>(&self, value: &Q) -> Option<&K>
where K: Borrow<Q> + Ord,

Returns a reference to the value in the set, if any, that is equal to the given value.

The value may be any borrowed form of the set’s value type, but the ordering on the borrowed form must match the ordering on the value type.

pub fn is_empty(&self) -> bool

Returns true if the set contains no elements.

pub fn len(&self) -> usize

Returns the number of items in the archived B-tree set.

pub fn resolve_from_len( len: usize, resolver: BTreeSetResolver, out: Place<Self>, )

Resolves a B-tree set from its length.

pub fn serialize_from_ordered_iter<I, KU, S>( iter: I, serializer: &mut S, ) -> Result<BTreeSetResolver, S::Error>
where I: ExactSizeIterator, I::Item: Borrow<KU>, KU: Serialize<S, Archived = K>, S: Fallible + Allocator + Writer + ?Sized, S::Error: Source,

Serializes an ArchivedBTreeSet from the given iterator and serializer.

pub fn visit<T>(&self, f: impl FnMut(&K) -> ControlFlow<T>) -> Option<T>

Visits every key in the B-tree with a function.

If f returns ControlFlow::Break, visit will return Some with the broken value. If f returns Continue for every key in the tree, visit will return None.