pub struct ArchivedIndexSet<K, H = FxHasher64> { /* private fields */ }Expand description
An archived IndexSet.
Implementations
Sourceimpl<K, H> ArchivedIndexSet<K, H>
impl<K, H> ArchivedIndexSet<K, H>
Sourceimpl<K, H: Default + Hasher> ArchivedIndexSet<K, H>
impl<K, H: Default + Hasher> ArchivedIndexSet<K, H>
Sourcepub fn get_full<Q>(&self, k: &Q) -> Option<(usize, &K)>
pub fn get_full<Q>(&self, k: &Q) -> Option<(usize, &K)>
Returns the item index and value stored in the set, if any.
Sourcepub fn get_index_of<Q>(&self, key: &Q) -> Option<usize>
pub fn get_index_of<Q>(&self, key: &Q) -> Option<usize>
Returns the index of a key if it exists in the set.
Sourcepub fn resolve_from_len(
len: usize,
load_factor: (usize, usize),
resolver: IndexSetResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, load_factor: (usize, usize), resolver: IndexSetResolver, out: Place<Self>, )
Resolves an archived index map from a given length and parameters.
Sourcepub fn serialize_from_iter<I, UK, S>(
iter: I,
load_factor: (usize, usize),
serializer: &mut S,
) -> Result<IndexSetResolver, S::Error>
pub fn serialize_from_iter<I, UK, S>( iter: I, load_factor: (usize, usize), serializer: &mut S, ) -> Result<IndexSetResolver, S::Error>
Serializes an iterator of keys as an index set.