ArchivedHashSet

Struct ArchivedHashSet 

pub struct ArchivedHashSet<K, H = FxHasher64> { /* private fields */ }
An archived HashSet. This is a wrapper around a hash map with the same key and unit value.

Implementations

Source

impl<K, H> ArchivedHashSet<K, H>

pub const fn len(&self) -> usize

Gets the number of items in the hash set.

pub const fn is_empty(&self) -> bool

Returns whether there are no items in the hash set.

pub fn iter(&self) -> Keys<'_, K, (), H>

Gets an iterator over the keys of the underlying hash map.

Source

impl<K, H: Hasher + Default> ArchivedHashSet<K, H>

pub fn get<Q>(&self, k: &Q) -> Option<&K>
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Gets the key corresponding to the given key in the hash set.

pub fn contains<Q>(&self, k: &Q) -> bool
where K: Borrow<Q>, Q: Hash + Eq + ?Sized,

Returns whether the given key is in the hash set.

pub fn resolve_from_len( len: usize, load_factor: (usize, usize), resolver: HashSetResolver, out: Place<Self>, )

Resolves an archived hash set from the given length and parameters.

pub fn serialize_from_iter<I, KU, S>( iter: I, load_factor: (usize, usize), serializer: &mut S, ) -> Result<HashSetResolver, S::Error>
where I: Clone + ExactSizeIterator, I::Item: Borrow<KU>, KU: Serialize<S, Archived = K> + Hash + Eq, S: Fallible + Writer + Allocator + ?Sized, S::Error: Source,

Serializes an iterator of keys as a hash set.