pub enum PoolingState {
Started,
Pending,
Finished(ErasedPtr),
}Expand description
The result of starting to deserialize a shared pointer.
Variants
Started
The caller started pooling this value. They should proceed to
deserialize the shared value and call finish_pooling.
Pending
Another caller started pooling this value, but has not finished yet. This can only occur with cyclic shared pointer structures, and so rkyv treats this as an error by default.
Finished(ErasedPtr)
This value has already been pooled. The caller should use the returned pointer to pool its value.