pub struct ErasedPtr { /* private fields */ }Expand description
A type-erased pointer.
Implementations
Sourceimpl ErasedPtr
impl ErasedPtr
Sourcepub fn new<T>(ptr: *mut T) -> Self
pub fn new<T>(ptr: *mut T) -> Self
Returns an erased pointer corresponding to the given pointer.
Sourcepub fn data_address(&self) -> *mut ()
pub fn data_address(&self) -> *mut ()
Returns the data address corresponding to this erased pointer.
Sourcepub unsafe fn downcast_unchecked<T>(&self) -> *mut T
pub unsafe fn downcast_unchecked<T>(&self) -> *mut T
Safety
self must be created from a valid pointer to T.