pub struct ArchivedIpv4Addr { /* private fields */ }Expand description
An archived Ipv4Addr.
Implementations
Sourceimpl ArchivedIpv4Addr
impl ArchivedIpv4Addr
Sourcepub const fn octets(&self) -> [u8; 4]
pub const fn octets(&self) -> [u8; 4]
Returns the four eight-bit integers that make up this address.
Sourcepub const fn is_broadcast(&self) -> bool
pub const fn is_broadcast(&self) -> bool
Returns true if this is a broadcast address (255.255.255.255).
See Ipv4Addr::is_broadcast for more details.
Sourcepub const fn is_documentation(&self) -> bool
pub const fn is_documentation(&self) -> bool
Returns true if this address is in a range designated for
documentation.
See Ipv4Addr::is_documentation for more details.
Sourcepub const fn is_link_local(&self) -> bool
pub const fn is_link_local(&self) -> bool
Returns true if the address is link-local (169.254.0.0/16).
See Ipv4Addr::is_link_local for more details.
Sourcepub const fn is_loopback(&self) -> bool
pub const fn is_loopback(&self) -> bool
Returns true if this is a loopback address (127.0.0.0/8).
See Ipv4Addr::is_loopback for more details.
Sourcepub const fn is_multicast(&self) -> bool
pub const fn is_multicast(&self) -> bool
Returns true if this is a multicast address (224.0.0.0/4).
See Ipv4Addr::is_multicast for more details.
Sourcepub const fn is_private(&self) -> bool
pub const fn is_private(&self) -> bool
Returns true if this is a private address.
See Ipv4Addr::is_private for more details.
Sourcepub const fn is_unspecified(&self) -> bool
pub const fn is_unspecified(&self) -> bool
Returns true for the special ‘unspecified’ address (0.0.0.0).
See Ipv4Addr::is_unspecified for more details.
Sourcepub const fn to_ipv6_compatible(&self) -> Ipv6Addr
pub const fn to_ipv6_compatible(&self) -> Ipv6Addr
Converts this address to an IPv4-compatible
IPv6 address.
See Ipv4Addr::to_ipv6_compatible for more
details.
Sourcepub const fn to_ipv6_mapped(&self) -> Ipv6Addr
pub const fn to_ipv6_mapped(&self) -> Ipv6Addr
Converts this address to an IPv4-mapped
IPv6 address.
See Ipv4Addr::to_ipv6_mapped for more details.