pub struct ArchivedIpv6Addr { /* private fields */ }Expand description
An archived Ipv6Addr.
Implementations
Sourceimpl ArchivedIpv6Addr
impl ArchivedIpv6Addr
Sourcepub const fn segments(&self) -> [u16; 8]
pub const fn segments(&self) -> [u16; 8]
Returns the eight 16-bit segments that make up this address.
Sourcepub const fn is_loopback(&self) -> bool
pub const fn is_loopback(&self) -> bool
Returns true if this is a loopback address (::1).
See Ipv6Addr::is_loopback() for
more details.
Sourcepub const fn is_multicast(&self) -> bool
pub const fn is_multicast(&self) -> bool
Returns true if this is a multicast address (ff00::/8).
See Ipv6Addr::is_multicast() for
more details.
Sourcepub const fn is_unspecified(&self) -> bool
pub const fn is_unspecified(&self) -> bool
Returns true for the special ‘unspecified’ address (::).
See Ipv6Addr::is_unspecified()
for more details.
Sourcepub const fn octets(&self) -> [u8; 16]
pub const fn octets(&self) -> [u8; 16]
Returns the sixteen eight-bit integers the IPv6 address consists of.