NichedOption

Struct NichedOption 

pub struct NichedOption<T, N: ?Sized> { /* private fields */ }
A niched ArchivedOption<T>.

It has the same layout as T, and thus uses less space by storing the None variant in a custom way based on N.

Implementations

Source

impl<T, N: Niching<T> + ?Sized> NichedOption<T, N>

pub fn is_none(&self) -> bool

Returns true if the option is a None value.

pub fn is_some(&self) -> bool

Returns true if the option is a Some value.

pub fn as_ref(&self) -> Option<&T>

Converts to an Option<&T>.

pub fn as_mut(&mut self) -> Option<&mut T>

Converts to an Option<&mut T>.

pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, T>>

Converts from Seal<'_, NichedOption<T, N>> to Option<Seal<'_, T>>.

pub fn iter(&self) -> Iter<&T>

Returns an iterator over the possibly-contained value.

pub fn iter_mut(&mut self) -> Iter<&mut T>

Returns an iterator over the mutable possibly-contained value.

pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, T>>

Returns an iterator over the sealed possibly-contained value.

pub fn resolve_from_option<U>( option: Option<&U>, resolver: Option<U::Resolver>, out: Place<Self>, )
where U: Archive<Archived = T>,

Resolves a NichedOption<U::Archived, N> from an Option<&U>.

pub fn serialize_from_option<U, S>( option: Option<&U>, serializer: &mut S, ) -> Result<Option<U::Resolver>, S::Error>
where U: Serialize<S, Archived = T>, S: Fallible + ?Sized,

Serializes a NichedOption<U::Archived, N> from an Option<&U>.

Source

impl<T, N> NichedOption<T, N>
where T: Deref, N: Niching<T> + ?Sized,

pub fn as_deref(&self) -> Option<&<T as Deref>::Target>

Converts from &NichedOption<T, N> to Option<&T::Target>.