ArchivedOptionBox

Struct ArchivedOptionBox 

pub struct ArchivedOptionBox<T: ArchivePointee + ?Sized> { /* private fields */ }
A niched archived Option<Box<T>>.

It uses less space by storing the None variant as a null pointer.

Implementations

Source

impl<T: ArchivePointee + ?Sized> ArchivedOptionBox<T>

pub fn is_none(&self) -> bool

Returns true if the option box is a None value.

pub fn is_some(&self) -> bool

Returns true if the option box is a Some value.

pub fn as_ref(&self) -> Option<&ArchivedBox<T>>

Converts to an Option<&ArchivedBox<T>>.

pub fn as_mut(&mut self) -> Option<&mut ArchivedBox<T>>

Converts to an Option<&mut ArchivedBox<T>>.

pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, ArchivedBox<T>>>

Converts from Seal<'_, ArchivedOption<T>> to Option<Seal<'_, ArchivedBox<T>>>.

pub fn iter(&self) -> Iter<&ArchivedBox<T>>

Returns an iterator over the possibly-contained value.

pub fn iter_mut(&mut self) -> Iter<&mut ArchivedBox<T>>

Returns an iterator over the mutable possibly-contained value.

pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, ArchivedBox<T>>>

Returns an iterator over the sealed possibly-contained value.

pub fn as_deref(&self) -> Option<&T>

Converts from &ArchivedOptionBox<T> to Option<&T>.

Leaves the original ArchivedOptionBox in-place, creating a new one with a reference to the original one.

Source

impl<T: ArchivePointee + ?Sized> ArchivedOptionBox<T>

pub fn resolve_from_option<U: ArchiveUnsized<Archived = T> + ?Sized>( field: Option<&U>, resolver: OptionBoxResolver, out: Place<Self>, )

Resolves an ArchivedOptionBox<T::Archived> from an Option<&T>.

pub fn serialize_from_option<U, S>( field: Option<&U>, serializer: &mut S, ) -> Result<OptionBoxResolver, S::Error>
where U: SerializeUnsized<S, Archived = T> + ?Sized, S: Fallible + Writer + ?Sized,

Serializes an ArchivedOptionBox<T::Archived> from an Option<&T>.