pub struct ArchivedOptionNonZeroI64 { /* private fields */ }Expand description
A niched archived Option<NonZeroI64>
Implementations
Sourceimpl ArchivedOptionNonZeroI64
impl ArchivedOptionNonZeroI64
Sourcepub fn as_ref(&self) -> Option<&Archived<NonZeroI64>>
pub fn as_ref(&self) -> Option<&Archived<NonZeroI64>>
Converts to an Option<&Archived<NonZeroI64>>
Sourcepub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroI64>>
pub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroI64>>
Converts to an Option<&mut Archived<NonZeroI64>>
Sourcepub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroI64>>>
pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroI64>>>
Converts from Seal<'_, ArchivedOptionNonZeroI64> to Option<Seal<'_, Archived<NonZeroI64>>>.
Sourcepub fn take(&mut self) -> Option<Archived<NonZeroI64>>
pub fn take(&mut self) -> Option<Archived<NonZeroI64>>
Takes the value out of the option, leaving a None in its
place.
Sourcepub fn iter(&self) -> Iter<&Archived<NonZeroI64>>
pub fn iter(&self) -> Iter<&Archived<NonZeroI64>>
Returns an iterator over the possibly-contained value.
Sourcepub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroI64>>
pub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroI64>>
Returns an iterator over the mutable possibly-contained value.
Sourcepub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroI64>>>
pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroI64>>>
Returns an iterator over the sealed mutable possibly-contained value.
Sourcepub fn get_or_insert(&mut self, v: NonZeroI64) -> &mut Archived<NonZeroI64>
pub fn get_or_insert(&mut self, v: NonZeroI64) -> &mut Archived<NonZeroI64>
Inserts v into the option if it is None, then returns a
mutable reference to the contained value.
Sourcepub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroI64>where
F: FnOnce() -> NonZeroI64,
pub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroI64>where
F: FnOnce() -> NonZeroI64,
Inserts a value computed from f into the option if it is
None, then returns a mutable reference to the contained value.
Sourcepub fn resolve_from_option(field: Option<NonZeroI64>, out: Place<Self>)
pub fn resolve_from_option(field: Option<NonZeroI64>, out: Place<Self>)
Resolves an ArchivedOptionNonZero from an Option<NonZero>.