pub struct ArchivedOptionNonZeroU32 { /* private fields */ }Expand description
A niched archived Option<NonZeroU32>
Implementations
Sourceimpl ArchivedOptionNonZeroU32
impl ArchivedOptionNonZeroU32
Sourcepub fn as_ref(&self) -> Option<&Archived<NonZeroU32>>
pub fn as_ref(&self) -> Option<&Archived<NonZeroU32>>
Converts to an Option<&Archived<NonZeroU32>>
Sourcepub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroU32>>
pub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroU32>>
Converts to an Option<&mut Archived<NonZeroU32>>
Sourcepub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroU32>>>
pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroU32>>>
Converts from Seal<'_, ArchivedOptionNonZeroU32> to Option<Seal<'_, Archived<NonZeroU32>>>.
Sourcepub fn take(&mut self) -> Option<Archived<NonZeroU32>>
pub fn take(&mut self) -> Option<Archived<NonZeroU32>>
Takes the value out of the option, leaving a None in its
place.
Sourcepub fn iter(&self) -> Iter<&Archived<NonZeroU32>>
pub fn iter(&self) -> Iter<&Archived<NonZeroU32>>
Returns an iterator over the possibly-contained value.
Sourcepub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroU32>>
pub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroU32>>
Returns an iterator over the mutable possibly-contained value.
Sourcepub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroU32>>>
pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroU32>>>
Returns an iterator over the sealed mutable possibly-contained value.
Sourcepub fn get_or_insert(&mut self, v: NonZeroU32) -> &mut Archived<NonZeroU32>
pub fn get_or_insert(&mut self, v: NonZeroU32) -> &mut Archived<NonZeroU32>
Inserts v into the option if it is None, then returns a
mutable reference to the contained value.
Sourcepub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroU32>where
F: FnOnce() -> NonZeroU32,
pub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroU32>where
F: FnOnce() -> NonZeroU32,
Inserts a value computed from f into the option if it is
None, then returns a mutable reference to the contained value.
Sourcepub fn resolve_from_option(field: Option<NonZeroU32>, out: Place<Self>)
pub fn resolve_from_option(field: Option<NonZeroU32>, out: Place<Self>)
Resolves an ArchivedOptionNonZero from an Option<NonZero>.