pub struct ArchivedOptionNonZeroU64 { /* private fields */ }Expand description
A niched archived Option<NonZeroU64>
Implementations
Sourceimpl ArchivedOptionNonZeroU64
impl ArchivedOptionNonZeroU64
Sourcepub fn as_ref(&self) -> Option<&Archived<NonZeroU64>>
pub fn as_ref(&self) -> Option<&Archived<NonZeroU64>>
Converts to an Option<&Archived<NonZeroU64>>
Sourcepub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroU64>>
pub fn as_mut(&mut self) -> Option<&mut Archived<NonZeroU64>>
Converts to an Option<&mut Archived<NonZeroU64>>
Sourcepub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroU64>>>
pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, Archived<NonZeroU64>>>
Converts from Seal<'_, ArchivedOptionNonZeroU64> to Option<Seal<'_, Archived<NonZeroU64>>>.
Sourcepub fn take(&mut self) -> Option<Archived<NonZeroU64>>
pub fn take(&mut self) -> Option<Archived<NonZeroU64>>
Takes the value out of the option, leaving a None in its
place.
Sourcepub fn iter(&self) -> Iter<&Archived<NonZeroU64>>
pub fn iter(&self) -> Iter<&Archived<NonZeroU64>>
Returns an iterator over the possibly-contained value.
Sourcepub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroU64>>
pub fn iter_mut(&mut self) -> Iter<&mut Archived<NonZeroU64>>
Returns an iterator over the mutable possibly-contained value.
Sourcepub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroU64>>>
pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, Archived<NonZeroU64>>>
Returns an iterator over the sealed mutable possibly-contained value.
Sourcepub fn get_or_insert(&mut self, v: NonZeroU64) -> &mut Archived<NonZeroU64>
pub fn get_or_insert(&mut self, v: NonZeroU64) -> &mut Archived<NonZeroU64>
Inserts v into the option if it is None, then returns a
mutable reference to the contained value.
Sourcepub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroU64>where
F: FnOnce() -> NonZeroU64,
pub fn get_or_insert_with<F>(&mut self, f: F) -> &mut Archived<NonZeroU64>where
F: FnOnce() -> NonZeroU64,
Inserts a value computed from f into the option if it is
None, then returns a mutable reference to the contained value.
Sourcepub fn resolve_from_option(field: Option<NonZeroU64>, out: Place<Self>)
pub fn resolve_from_option(field: Option<NonZeroU64>, out: Place<Self>)
Resolves an ArchivedOptionNonZero from an Option<NonZero>.