pub type ArchivedUsize = ArchivedU32;Expand description
The archived version of isize chosen based on the currently-enabled
pointer_width_* feature.
Aliased Type
pub struct ArchivedUsize(/* private fields */);pub type ArchivedUsize = ArchivedU32;The archived version of isize chosen based on the currently-enabled
pointer_width_* feature.
pub struct ArchivedUsize(/* private fields */);