FixedUsize

Type Alias FixedUsize 

pub type FixedUsize = u32;
The native type that usize is converted to for archiving.

This will be u16, u32, or u64 when the pointer_width_16, pointer_width_32, or pointer_width_64 features are enabled, respectively. With no pointer width features enabled, it defaults to u32.