RelPtr

Struct RelPtr 

pub struct RelPtr<T: ArchivePointee + ?Sized, O> { /* private fields */ }
A pointer which resolves to relative to its position in memory.

This is a strongly-typed version of RawRelPtr.

See Archive for an example of creating one.

Implementations

Source

impl<T, O: Offset> RelPtr<T, O>

pub fn try_emplace<E: Source>(to: usize, out: Place<Self>) -> Result<(), E>

Attempts to create a relative pointer from one position to another.

pub fn emplace(to: usize, out: Place<Self>)

Creates a relative pointer from one position to another.

Panics
  • If the offset between from and to does not fit in an isize
  • If the offset between from and to exceeds the offset storage
Source

impl<T: ArchivePointee + ?Sized, O: Offset> RelPtr<T, O>

pub fn try_emplace_invalid<E: Source>(out: Place<Self>) -> Result<(), E>

Attempts to create an invalid relative pointer with default metadata.

pub fn emplace_invalid(out: Place<Self>)

Creates an invalid relative pointer with default metadata.

Panics
  • If an offset of 1 does not fit in an isize
  • If an offset of 1 exceeds the offset storage
pub fn try_emplace_unsized<E: Source>( to: usize, metadata: T::ArchivedMetadata, out: Place<Self>, ) -> Result<(), E>

Attempts to create a relative pointer from one position to another.

pub fn emplace_unsized( to: usize, metadata: T::ArchivedMetadata, out: Place<Self>, )

Creates a relative pointer from one position to another.

Panics
  • If the offset between from and to does not fit in an isize
  • If the offset between from and to exceeds the offset storage
pub fn base_raw(this: *mut Self) -> *mut u8

Gets the base pointer for the pointed-to relative pointer.

pub unsafe fn offset_raw(this: *mut Self) -> isize

Gets the offset of the pointed-to relative pointer from its base.

Safety

this must be non-null, properly-aligned, and point to a valid RelPtr.

pub unsafe fn as_ptr_raw(this: *mut Self) -> *mut T

Calculates the memory address being pointed to by the pointed-to relative pointer.

Safety
  • this must be non-null, properly-aligned, and point to a valid RelPtr.
  • The offset of this relative pointer, when added to its base, must be located in the same allocated object as it.
pub unsafe fn as_ptr_wrapping_raw(this: *mut Self) -> *mut T

Calculates the memory address being pointed to by the pointed-to relative pointer using wrapping methods.

This method is a safer but potentially slower version of as_ptr_raw.

Safety

this must be non-null, properly-aligned, and point to a valid RelPtr.

pub unsafe fn is_invalid_raw(this: *mut Self) -> bool

Gets whether the offset of the pointed-to relative pointer is invalid.

Safety

this must be non-null, properly-aligned, and point to a valid RawRelPtr.

pub fn base(&self) -> *const u8

Gets the base pointer for the relative pointer.

pub fn base_mut(this: Seal<'_, Self>) -> *mut u8

Gets the mutable base pointer for this relative pointer.

pub fn offset(&self) -> isize

Gets the offset of the relative pointer from its base.

pub fn is_invalid(&self) -> bool

Gets whether the offset of the relative pointer is 0.

pub fn metadata(&self) -> &T::ArchivedMetadata

Gets the metadata of the relative pointer.

pub unsafe fn as_ptr(&self) -> *const T

Calculates the memory address being pointed to by this relative pointer.

Safety

The offset of this relative pointer, when added to its base, must be located in the same allocated object as it.

pub unsafe fn as_mut_ptr(this: Seal<'_, Self>) -> *mut T

Calculates the mutable memory address being pointed to by this relative pointer.

Safety

The offset of this relative pointer, when added to its base, must be located in the same allocated object as it.

pub fn as_ptr_wrapping(&self) -> *const T

Calculates the memory address being pointed to by this relative pointer using wrapping methods.

This method is a safer but potentially slower version of as_ptr.

pub fn as_mut_ptr_wrapping(this: Seal<'_, Self>) -> *mut T

Calculates the mutable memory address being pointed to by this relative pointer using wrapping methods.

This method is a safer but potentially slower version of as_ptr.