pub type RawRelPtrI16 = RawRelPtr<ArchivedI16>;Expand description
A raw relative pointer that uses an archived i16 as the underlying offset.
Aliased Type
pub struct RawRelPtrI16 { /* private fields */ }pub type RawRelPtrI16 = RawRelPtr<ArchivedI16>;A raw relative pointer that uses an archived i16 as the underlying offset.
pub struct RawRelPtrI16 { /* private fields */ }