pub type RawRelPtrI32 = RawRelPtr<ArchivedI32>;Expand description
A raw relative pointer that uses an archived i32 as the underlying offset.
Aliased Type
pub struct RawRelPtrI32 { /* private fields */ }pub type RawRelPtrI32 = RawRelPtr<ArchivedI32>;A raw relative pointer that uses an archived i32 as the underlying offset.
pub struct RawRelPtrI32 { /* private fields */ }