pub type RawRelPtrI64 = RawRelPtr<ArchivedI64>;Expand description
A raw relative pointer that uses an archived i64 as the underlying offset.
Aliased Type
pub struct RawRelPtrI64 { /* private fields */ }pub type RawRelPtrI64 = RawRelPtr<ArchivedI64>;A raw relative pointer that uses an archived i64 as the underlying offset.
pub struct RawRelPtrI64 { /* private fields */ }