pub type RawRelPtrU16 = RawRelPtr<ArchivedU16>;Expand description
A raw relative pointer that uses an archived u16 as the underlying offset.
Aliased Type
pub struct RawRelPtrU16 { /* private fields */ }pub type RawRelPtrU16 = RawRelPtr<ArchivedU16>;A raw relative pointer that uses an archived u16 as the underlying offset.
pub struct RawRelPtrU16 { /* private fields */ }