pub type RawRelPtrU32 = RawRelPtr<ArchivedU32>;Expand description
A raw relative pointer that uses an archived u32 as the underlying offset.
Aliased Type
pub struct RawRelPtrU32 { /* private fields */ }pub type RawRelPtrU32 = RawRelPtr<ArchivedU32>;A raw relative pointer that uses an archived u32 as the underlying offset.
pub struct RawRelPtrU32 { /* private fields */ }