pub type RawRelPtrU64 = RawRelPtr<ArchivedU64>;Expand description
A raw relative pointer that uses an archived u64 as the underlying offset.
Aliased Type
pub struct RawRelPtrU64 { /* private fields */ }pub type RawRelPtrU64 = RawRelPtr<ArchivedU64>;A raw relative pointer that uses an archived u64 as the underlying offset.
pub struct RawRelPtrU64 { /* private fields */ }