Iter

Type Alias Iter 

pub type Iter<P> = Iter<P>;
An iterator over a reference to the Ok variant of an ArchivedResult.

The iterator yields one value if the result is Ok, otherwise none.

Created by ArchivedResult::iter.

Aliased Type

pub struct Iter<P> { /* private fields */ }