AllocationStats

Struct AllocationStats 

pub struct AllocationStats {
    pub max_bytes_allocated: usize,
    pub max_allocations: usize,
    pub max_alignment: usize,
    /* private fields */
}
Statistics for the allocations which occurred during serialization.

Fields

max_bytes_allocated: usize

Returns the maximum number of bytes that were concurrently allocated.

max_allocations: usize

Returns the maximum number of concurrent allocations.

max_alignment: usize

Returns the maximum alignment of requested allocations.

Implementations

Source

impl AllocationStats

pub fn min_arena_capacity(&self) -> usize

Returns the minimum arena capacity required to serialize the same data.

This calculation takes into account packing efficiency for slab allocated space. It is not exact, and has an error bound of max_allocations * (max_alignment - 1) bytes. This should be suitably small for most use cases.

pub fn min_arena_capacity_max_error(&self) -> usize

Returns the maximum error term for the minimum arena capacity calculation.