pub trait Writer<E = <Self as Fallible>::Error>: Positional {
// Required method
fn write(&mut self, bytes: &[u8]) -> Result<(), E>;
}Expand description
A type that writes bytes to some output.
A type that is Write can be wrapped in an IoWriter
to equip it with Writer.
It’s important that the memory for archived objects is properly aligned
before attempting to read objects out of it; use an
AlignedVec or the Align
wrapper as appropriate.