pub struct IoWriter<W> { /* private fields */ }Expand description
Wraps a type that implements io::Write and equips it
with Writer.
Examples
use rkyv::rancor::{Error, Strategy};
let mut io_writer = IoWriter::new(Vec::new());
// In most cases, calling a method like `serialize` will wrap the writer in
// a Strategy for us.
let mut writer = Strategy::<_, Error>::wrap(&mut io_writer);
assert_eq!(writer.pos(), 0);
writer.write(&[0u8, 1u8, 2u8, 3u8]);
assert_eq!(writer.pos(), 4);
let buf = io_writer.into_inner();
assert_eq!(buf.len(), 4);
assert_eq!(buf, vec![0u8, 1u8, 2u8, 3u8]);Implementations
Sourceimpl<W> IoWriter<W>
impl<W> IoWriter<W>
Sourcepub fn with_pos(inner: W, pos: usize) -> Self
pub fn with_pos(inner: W, pos: usize) -> Self
Creates a new serializer from a writer, and assumes that the underlying writer is currently at the given position.
Sourcepub fn into_inner(self) -> W
pub fn into_inner(self) -> W
Consumes the serializer and returns the internal writer used to create it.