clear_arena

Function clear_arena 

pub fn clear_arena()
Clears the builtin arena allocator.

When the std feature is enabled, this only clears the allocator for the current thread. When atomic pointers are supported, this will clear the allocator for all threads. Otherwise, this function does nothing.