ArchiveValidator

Struct ArchiveValidator 

pub struct ArchiveValidator<'a> { /* private fields */ }
A validator that can verify archives with nonlocal memory.

Implementations

Source

impl<'a> ArchiveValidator<'a>

pub fn new(bytes: &'a [u8]) -> Self

Creates a new bounds validator for the given bytes.

pub fn with_max_depth( bytes: &'a [u8], max_subtree_depth: Option<NonZeroUsize>, ) -> Self

Crates a new bounds validator for the given bytes with a maximum validation depth.