pub enum ValidationState {
Started,
Pending,
Finished,
}Expand description
The result of starting to validate a shared pointer.
Variants
Started
The caller started validating this value. They should proceed to check
the shared value and call finish_shared.
Pending
Another caller started validating this value, but has not finished yet. This can only occur with cyclic shared pointer structures, and so rkyv treats this as an error by default.
Finished
This value has already been validated.