AtomicLoad

Struct AtomicLoad 

pub struct AtomicLoad<SO> { /* private fields */ }
A wrapper that archives an atomic by loading its value with a particular ordering.

When serializing, the specified ordering will be used to load the value from the source atomic. The underlying archived type is still a non-atomic value.

Example

use core::sync::atomic::AtomicU32;

use rkyv::{
    with::{AtomicLoad, Relaxed},
    Archive,
};

#[derive(Archive)]
struct Example {
    #[rkyv(with = AtomicLoad<Relaxed>)]
    a: AtomicU32,
}