pub struct Identity;Expand description
A no-op wrapper which uses the default impls for the type.
This is most useful for wrappers like MapKV when you only want to apply
a wrapper to either the key or the value.
Example
use std::collections::HashMap;
use rkyv::{
with::{Identity, Inline, MapKV},
Archive,
};
#[derive(Archive)]
struct Example<'a> {
#[rkyv(with = MapKV<Identity, Inline>)]
a: HashMap<u32, &'a u32>,
}Trait Implementations
Sourceimpl<F: Archive> ArchiveWith<F> for Identity
impl<F: Archive> ArchiveWith<F> for Identity
Sourceimpl<F, T, D> DeserializeWith<F, T, D> for Identity
impl<F, T, D> DeserializeWith<F, T, D> for Identity