InlineAsBox

Struct InlineAsBox 

pub struct InlineAsBox;
A wrapper that serializes a reference as if it were boxed.

Unlike Inline, unsized references can be serialized with InlineAsBox.

References serialized with InlineAsBox cannot be deserialized because the struct cannot own the deserialized value.

Example

use rkyv::{with::InlineAsBox, Archive};

#[derive(Archive)]
struct Example<'a> {
    #[rkyv(with = InlineAsBox)]
    a: &'a i32,
    #[rkyv(with = InlineAsBox)]
    b: &'a str,
}