Lock

Struct Lock 

pub struct Lock;
A wrapper that locks a lock and serializes the value immutably.

This wrapper can panic under very specific circumstances when:

  1. serialize_with is called and succeeds in locking the value to serialize it.
  2. Another thread locks the value and panics, poisoning the lock
  3. resolve_with is called and gets a poisoned value.

Unfortunately, it’s not possible to work around this issue internally. Users must ensure this doesn’t happen on their own through manual synchronization or guaranteeing that panics do not occur while holding locks.

Example

use std::sync::Mutex;

use rkyv::{with::Lock, Archive};

#[derive(Archive)]
struct Example {
    #[rkyv(with = Lock)]
    a: Mutex<i32>,
}