Map

Struct Map 

pub struct Map<T> { /* private fields */ }
A wrapper that applies another wrapper to the values contained in a type. This can be applied to a vector to map each element, or an option to map any contained value.

See ArchiveWith for more details.

Example

use rkyv::{
    with::{InlineAsBox, Map},
    Archive,
};

#[derive(Archive)]
struct Example<'a> {
    // This will apply `InlineAsBox` to the `&i32` contained in this option
    #[rkyv(with = Map<InlineAsBox>)]
    option: Option<&'a i32>,
    // This will apply `InlineAsBox` to each `&i32` contained in this vector
    #[rkyv(with = Map<InlineAsBox>)]
    vec: Vec<&'a i32>,
}