MapKV

Struct MapKV 

pub struct MapKV<K, V> { /* private fields */ }
A wrapper that applies key and value wrappers to the key-value pairs contained in a type. This can be applied to a hash map or B-tree map to map the key-value pairs.

Example

use std::collections::HashMap;

use rkyv::{
    with::{Inline, InlineAsBox, MapKV},
    Archive,
};

#[derive(Archive)]
struct Example<'a> {
    // This will apply `InlineAsBox` to the `&str` key, and `Inline` to the
    // `&str` value.
    #[rkyv(with = MapKV<InlineAsBox, Inline>)]
    hash_map: HashMap<&'a str, &'a str>,
}