Unsafe

Struct Unsafe 

pub struct Unsafe;
A wrapper that allows serialize-unsafe types to be serialized.

Types like Cell and UnsafeCell may contain serializable types, but have unsafe access semantics due to interior mutability. They may be safe to serialize, but only under conditions that rkyv is unable to guarantee.

This wrapper enables serializing these types, and places the burden of verifying that their access semantics are used safely on the user.

Safety

Using this wrapper on types with interior mutability can create races conditions or allow access to data in an invalid state if access semantics are not followed properly. During serialization, the data must not be modified.

Example

use core::cell::{Cell, UnsafeCell};

use rkyv::{with::Unsafe, Archive};

#[derive(Archive)]
struct Example {
    #[rkyv(with = Unsafe)]
    cell: Cell<String>,
    #[rkyv(with = Unsafe)]
    unsafe_cell: UnsafeCell<String>,
}