With

Struct With 

pub struct With<F: ?Sized, W> { /* private fields */ }
A transparent wrapper which applies a “with” type.

With wraps a reference to a type and applies the specified wrapper type when serializing and deserializing.

Implementations

Source

impl<F: ?Sized, W> With<F, W>

pub fn cast(field: &F) -> &Self

Casts a With reference from a reference to the underlying field.