pub struct ArchivedBTreeMap<K, V, const E: usize = 5> { /* private fields */ }Expand description
An archived BTreeMap.
Implementations
Sourceimpl<K, V, const E: usize> ArchivedBTreeMap<K, V, E>
impl<K, V, const E: usize> ArchivedBTreeMap<K, V, E>
Sourcepub fn iter(&self) -> Iter<'_, K, V, E> ⓘ
pub fn iter(&self) -> Iter<'_, K, V, E> ⓘ
Gets an iterator over the entries of the map, sorted by key.
Sourcepub fn iter_seal(this: Seal<'_, Self>) -> IterSeal<'_, K, V, E> ⓘ
pub fn iter_seal(this: Seal<'_, Self>) -> IterSeal<'_, K, V, E> ⓘ
Gets a mutable iterator over the entires of the map, sorted by key.
Sourcepub fn values_seal(this: Seal<'_, Self>) -> ValuesSeal<'_, K, V, E> ⓘ
pub fn values_seal(this: Seal<'_, Self>) -> ValuesSeal<'_, K, V, E> ⓘ
Gets a mutable iterator over the values of the map.
Sourcepub fn range<Q, R>(&self, range: R) -> Range<'_, K, V, E> ⓘ
pub fn range<Q, R>(&self, range: R) -> Range<'_, K, V, E> ⓘ
Gets an iterator over a sub-range of entries, sorted by key.
Sourcepub fn range_with<Q, R, C>(&self, range: R, cmp: C) -> Range<'_, K, V, E> ⓘ
pub fn range_with<Q, R, C>(&self, range: R, cmp: C) -> Range<'_, K, V, E> ⓘ
Gets an iterator over a sub-range of entries, sorted by key.
This method uses the supplied comparison function to compare the range to elements.
Sourcepub fn range_seal<Q, R>(
this: Seal<'_, Self>,
range: R,
) -> RangeSeal<'_, K, V, E> ⓘ
pub fn range_seal<Q, R>( this: Seal<'_, Self>, range: R, ) -> RangeSeal<'_, K, V, E> ⓘ
Gets a mutable iterator over a sub-range of entries, sorted by key.
Sourcepub fn range_seal_with<Q, R, C>(
this: Seal<'_, Self>,
range: R,
cmp: C,
) -> RangeSeal<'_, K, V, E> ⓘ
pub fn range_seal_with<Q, R, C>( this: Seal<'_, Self>, range: R, cmp: C, ) -> RangeSeal<'_, K, V, E> ⓘ
Gets a mutable iterator over a sub-range of entries, sorted by key.
This method uses the supplied comparison function to compare the range to elements.
Sourceimpl<K, V, const E: usize> ArchivedBTreeMap<K, V, E>
impl<K, V, const E: usize> ArchivedBTreeMap<K, V, E>
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns whether the B-tree map contains the given key.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Returns the value associated with the given key, or None if the key is
not present in the B-tree map.
Sourcepub fn get_seal<'a, Q>(this: Seal<'a, Self>, key: &Q) -> Option<Seal<'a, V>>
pub fn get_seal<'a, Q>(this: Seal<'a, Self>, key: &Q) -> Option<Seal<'a, V>>
Returns the mutable value associated with the given key, or None if
the key is not present in the B-tree map.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
Gets the key-value pair associated with the given key, or None if the
key is not present in the B-tree map.
Sourcepub fn get_key_value_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(&K, &V)>
pub fn get_key_value_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(&K, &V)>
Gets the key-value pair associated with the given key, or None if the
key is not present in the B-tree map.
This method uses the supplied comparison function to compare the key to elements.
Sourcepub fn get_key_value_seal<'a, Q>(
this: Seal<'a, Self>,
key: &Q,
) -> Option<(&'a K, Seal<'a, V>)>
pub fn get_key_value_seal<'a, Q>( this: Seal<'a, Self>, key: &Q, ) -> Option<(&'a K, Seal<'a, V>)>
Gets the mutable key-value pair associated with the given key, or None
if the key is not present in the B-tree map.
Sourcepub fn get_key_value_seal_with<'a, Q, C>(
this: Seal<'a, Self>,
key: &Q,
cmp: C,
) -> Option<(&'a K, Seal<'a, V>)>
pub fn get_key_value_seal_with<'a, Q, C>( this: Seal<'a, Self>, key: &Q, cmp: C, ) -> Option<(&'a K, Seal<'a, V>)>
Gets the mutable key-value pair associated with the given key, or None
if the key is not present in the B-tree map.
This method uses the supplied comparison function to compare the key to elements.
Sourcepub fn resolve_from_len(
len: usize,
resolver: BTreeMapResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, resolver: BTreeMapResolver, out: Place<Self>, )
Resolves an ArchivedBTreeMap from the given length, resolver, and
output place.
Sourcepub fn serialize_from_ordered_iter<I, BKU, BVU, KU, VU, S>(
iter: I,
serializer: &mut S,
) -> Result<BTreeMapResolver, S::Error>
pub fn serialize_from_ordered_iter<I, BKU, BVU, KU, VU, S>( iter: I, serializer: &mut S, ) -> Result<BTreeMapResolver, S::Error>
Serializes an ArchivedBTreeMap from the given iterator and serializer.
Sourcepub fn visit<T>(&self, f: impl FnMut(&K, &V) -> ControlFlow<T>) -> Option<T>
pub fn visit<T>(&self, f: impl FnMut(&K, &V) -> ControlFlow<T>) -> Option<T>
Visits every key-value pair in the B-tree with a function.
If f returns ControlFlow::Break, visit will return Some with the
broken value. If f returns Continue for every pair in the tree,
visit will return None.
Sourcepub fn visit_seal<T>(
this: Seal<'_, Self>,
f: impl FnMut(&K, Seal<'_, V>) -> ControlFlow<T>,
) -> Option<T>
pub fn visit_seal<T>( this: Seal<'_, Self>, f: impl FnMut(&K, Seal<'_, V>) -> ControlFlow<T>, ) -> Option<T>
Visits every mutable key-value pair in the B-tree with a function.
If f returns ControlFlow::Break, visit will return Some with the
broken value. If f returns Continue for every pair in the tree,
visit will return None.