pub struct ArchivedBTreeSet<K, const E: usize = 5>(/* private fields */);Expand description
An archived BTreeSet. This is a wrapper around a B-tree map with the same
key and a value of ().
Implementations
Sourceimpl<K, const E: usize> ArchivedBTreeSet<K, E>
impl<K, const E: usize> ArchivedBTreeSet<K, E>
Sourceimpl<K, const E: usize> ArchivedBTreeSet<K, E>
impl<K, const E: usize> ArchivedBTreeSet<K, E>
Sourcepub fn contains_key<Q: Ord + ?Sized>(&self, key: &Q) -> bool
pub fn contains_key<Q: Ord + ?Sized>(&self, key: &Q) -> bool
Returns true if the set contains a value for the specified key.
The key may be any borrowed form of the set’s key type, but the ordering on the borrowed form must match the ordering on the key type.
Sourcepub fn get<Q: Ord + ?Sized>(&self, value: &Q) -> Option<&K>
pub fn get<Q: Ord + ?Sized>(&self, value: &Q) -> Option<&K>
Returns a reference to the value in the set, if any, that is equal to the given value.
The value may be any borrowed form of the set’s value type, but the ordering on the borrowed form must match the ordering on the value type.
Sourcepub fn resolve_from_len(
len: usize,
resolver: BTreeSetResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, resolver: BTreeSetResolver, out: Place<Self>, )
Resolves a B-tree set from its length.
Sourcepub fn serialize_from_ordered_iter<I, KU, S>(
iter: I,
serializer: &mut S,
) -> Result<BTreeSetResolver, S::Error>
pub fn serialize_from_ordered_iter<I, KU, S>( iter: I, serializer: &mut S, ) -> Result<BTreeSetResolver, S::Error>
Serializes an ArchivedBTreeSet from the given iterator and serializer.