pub struct ArchivedIndexMap<K, V, H = FxHasher64> { /* private fields */ }Expand description
An archived IndexMap.
Implementations
Sourceimpl<K, V, H> ArchivedIndexMap<K, V, H>
impl<K, V, H> ArchivedIndexMap<K, V, H>
Sourceimpl<K, V, H: Hasher + Default> ArchivedIndexMap<K, V, H>
impl<K, V, H: Hasher + Default> ArchivedIndexMap<K, V, H>
Sourcepub fn get_full_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(usize, &K, &V)>
pub fn get_full_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(usize, &K, &V)>
Gets the index, key, and value corresponding to the supplied key using the given comparison function.
Sourcepub fn get_full<Q>(&self, key: &Q) -> Option<(usize, &K, &V)>
pub fn get_full<Q>(&self, key: &Q) -> Option<(usize, &K, &V)>
Gets the index, key, and value corresponding to the supplied key.
Sourcepub fn get_key_value_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(&K, &V)>
pub fn get_key_value_with<Q, C>(&self, key: &Q, cmp: C) -> Option<(&K, &V)>
Returns the key-value pair corresponding to the supplied key using the given comparison function.
Sourcepub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
pub fn get_key_value<Q>(&self, key: &Q) -> Option<(&K, &V)>
Returns the key-value pair corresponding to the supplied key.
Sourcepub fn get_with<Q, C>(&self, key: &Q, cmp: C) -> Option<&V>
pub fn get_with<Q, C>(&self, key: &Q, cmp: C) -> Option<&V>
Returns a reference to the value corresponding to the supplied key using the given comparison function.
Sourcepub fn get<Q>(&self, key: &Q) -> Option<&V>
pub fn get<Q>(&self, key: &Q) -> Option<&V>
Returns a reference to the value corresponding to the supplied key.
Sourcepub fn get_full_seal_with<'a, Q, C>(
this: Seal<'a, Self>,
key: &Q,
cmp: C,
) -> Option<(usize, &'a K, Seal<'a, V>)>
pub fn get_full_seal_with<'a, Q, C>( this: Seal<'a, Self>, key: &Q, cmp: C, ) -> Option<(usize, &'a K, Seal<'a, V>)>
Gets the mutable index, key, and value corresponding to the supplied key using the given comparison function.
Sourcepub fn get_full_seal<'a, Q>(
this: Seal<'a, Self>,
key: &Q,
) -> Option<(usize, &'a K, Seal<'a, V>)>
pub fn get_full_seal<'a, Q>( this: Seal<'a, Self>, key: &Q, ) -> Option<(usize, &'a K, Seal<'a, V>)>
Gets the mutable index, key, and value corresponding to the supplied key.
Sourcepub fn get_key_value_seal_with<'a, Q, C>(
this: Seal<'a, Self>,
key: &Q,
cmp: C,
) -> Option<(&'a K, Seal<'a, V>)>
pub fn get_key_value_seal_with<'a, Q, C>( this: Seal<'a, Self>, key: &Q, cmp: C, ) -> Option<(&'a K, Seal<'a, V>)>
Returns the mutable key-value pair corresponding to the supplied key using the given comparison function.
Sourcepub fn get_key_value_seal<'a, Q>(
this: Seal<'a, Self>,
key: &Q,
) -> Option<(&'a K, Seal<'a, V>)>
pub fn get_key_value_seal<'a, Q>( this: Seal<'a, Self>, key: &Q, ) -> Option<(&'a K, Seal<'a, V>)>
Returns the mutable key-value pair corresponding to the supplied key.
Sourcepub fn get_seal_with<'a, Q, C>(
this: Seal<'a, Self>,
key: &Q,
cmp: C,
) -> Option<Seal<'a, V>>
pub fn get_seal_with<'a, Q, C>( this: Seal<'a, Self>, key: &Q, cmp: C, ) -> Option<Seal<'a, V>>
Returns a mutable reference to the value corresponding to the supplied key using the given comparison function.
Sourcepub fn get_seal<'a, Q>(this: Seal<'a, Self>, key: &Q) -> Option<Seal<'a, V>>
pub fn get_seal<'a, Q>(this: Seal<'a, Self>, key: &Q) -> Option<Seal<'a, V>>
Returns a mutable reference to the value corresponding to the supplied key.
Sourcepub fn contains_key<Q>(&self, key: &Q) -> bool
pub fn contains_key<Q>(&self, key: &Q) -> bool
Returns whether a key is present in the hash map.
Sourcepub fn get_index_of_with<Q, C>(&self, key: &Q, cmp: C) -> Option<usize>
pub fn get_index_of_with<Q, C>(&self, key: &Q, cmp: C) -> Option<usize>
Gets the index of a key if it exists in the map using the given comparison function.
Sourcepub fn get_index_of<Q>(&self, key: &Q) -> Option<usize>
pub fn get_index_of<Q>(&self, key: &Q) -> Option<usize>
Gets the index of a key if it exists in the map.
Sourcepub fn resolve_from_len(
len: usize,
load_factor: (usize, usize),
resolver: IndexMapResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, load_factor: (usize, usize), resolver: IndexMapResolver, out: Place<Self>, )
Resolves an archived index map from a given length and parameters.
Sourcepub fn serialize_from_iter<I, BKU, BVU, KU, VU, S>(
iter: I,
load_factor: (usize, usize),
serializer: &mut S,
) -> Result<IndexMapResolver, S::Error>
pub fn serialize_from_iter<I, BKU, BVU, KU, VU, S>( iter: I, load_factor: (usize, usize), serializer: &mut S, ) -> Result<IndexMapResolver, S::Error>
Serializes an iterator of key-value pairs as an index map.