pub struct ArchivedHashSet<K, H = FxHasher64> { /* private fields */ }Expand description
An archived HashSet. This is a wrapper around a hash map with the same key
and unit value.
Implementations
Sourceimpl<K, H> ArchivedHashSet<K, H>
impl<K, H> ArchivedHashSet<K, H>
Sourceimpl<K, H: Hasher + Default> ArchivedHashSet<K, H>
impl<K, H: Hasher + Default> ArchivedHashSet<K, H>
Sourcepub fn get<Q>(&self, k: &Q) -> Option<&K>
pub fn get<Q>(&self, k: &Q) -> Option<&K>
Gets the key corresponding to the given key in the hash set.
Sourcepub fn resolve_from_len(
len: usize,
load_factor: (usize, usize),
resolver: HashSetResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, load_factor: (usize, usize), resolver: HashSetResolver, out: Place<Self>, )
Resolves an archived hash set from the given length and parameters.
Sourcepub fn serialize_from_iter<I, KU, S>(
iter: I,
load_factor: (usize, usize),
serializer: &mut S,
) -> Result<HashSetResolver, S::Error>
pub fn serialize_from_iter<I, KU, S>( iter: I, load_factor: (usize, usize), serializer: &mut S, ) -> Result<HashSetResolver, S::Error>
Serializes an iterator of keys as a hash set.