pub struct ArchivedHashTable<T> { /* private fields */ }Expand description
A low-level archived SwissTable hash table with explicit hashing.
Implementations
Sourceimpl<T> ArchivedHashTable<T>
impl<T> ArchivedHashTable<T>
Sourcepub fn get_with<C>(&self, hash: u64, cmp: C) -> Option<&T>
pub fn get_with<C>(&self, hash: u64, cmp: C) -> Option<&T>
Returns the key-value pair corresponding to the supplied key.
Sourcepub fn get_seal_with<C>(
this: Seal<'_, Self>,
hash: u64,
cmp: C,
) -> Option<Seal<'_, T>>
pub fn get_seal_with<C>( this: Seal<'_, Self>, hash: u64, cmp: C, ) -> Option<Seal<'_, T>>
Returns the mutable key-value pair corresponding to the supplied key.
Sourcepub fn raw_iter(&self) -> RawIter<T> ⓘ
pub fn raw_iter(&self) -> RawIter<T> ⓘ
Returns an iterator over the entry pointers in the hash table.
Sourcepub fn raw_iter_seal(this: Seal<'_, Self>) -> RawIter<T> ⓘ
pub fn raw_iter_seal(this: Seal<'_, Self>) -> RawIter<T> ⓘ
Returns a sealed iterator over the entry pointers in the hash table.
Sourcepub fn serialize_from_iter<I, U, H, S>(
items: I,
hashes: H,
load_factor: (usize, usize),
serializer: &mut S,
) -> Result<HashTableResolver, S::Error>
pub fn serialize_from_iter<I, U, H, S>( items: I, hashes: H, load_factor: (usize, usize), serializer: &mut S, ) -> Result<HashTableResolver, S::Error>
Serializes an iterator of items as a hash table.
Sourcepub fn resolve_from_len(
len: usize,
load_factor: (usize, usize),
resolver: HashTableResolver,
out: Place<Self>,
)
pub fn resolve_from_len( len: usize, load_factor: (usize, usize), resolver: HashTableResolver, out: Place<Self>, )
Resolves an archived hash table from a given length and parameters.