pub struct NichedOption<T, N: ?Sized> { /* private fields */ }Expand description
A niched ArchivedOption<T>.
It has the same layout as T, and thus uses less space by storing the
None variant in a custom way based on N.
Implementations
Sourceimpl<T, N: Niching<T> + ?Sized> NichedOption<T, N>
impl<T, N: Niching<T> + ?Sized> NichedOption<T, N>
Sourcepub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, T>>
pub fn as_seal(this: Seal<'_, Self>) -> Option<Seal<'_, T>>
Converts from Seal<'_, NichedOption<T, N>> to Option<Seal<'_, T>>.
Sourcepub fn iter_mut(&mut self) -> Iter<&mut T>
pub fn iter_mut(&mut self) -> Iter<&mut T>
Returns an iterator over the mutable possibly-contained value.
Sourcepub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, T>>
pub fn iter_seal(this: Seal<'_, Self>) -> Iter<Seal<'_, T>>
Returns an iterator over the sealed possibly-contained value.