pub type FixedIsize = i32;Expand description
The native type that isize is converted to for archiving.
This will be i16, i32, or i64 when the pointer_width_16,
pointer_width_32, or pointer_width_64 features are enabled,
respectively. With no pointer width features enabled, it defaults to i32.