pub struct AllocationStats {
pub max_bytes_allocated: usize,
pub max_allocations: usize,
pub max_alignment: usize,
/* private fields */
}Expand description
Statistics for the allocations which occurred during serialization.
Fields
max_bytes_allocated: usizeReturns the maximum number of bytes that were concurrently allocated.
max_allocations: usizeReturns the maximum number of concurrent allocations.
max_alignment: usizeReturns the maximum alignment of requested allocations.
Implementations
Sourceimpl AllocationStats
impl AllocationStats
Sourcepub fn min_arena_capacity(&self) -> usize
pub fn min_arena_capacity(&self) -> usize
Returns the minimum arena capacity required to serialize the same data.
This calculation takes into account packing efficiency for slab
allocated space. It is not exact, and has an error bound of
max_allocations * (max_alignment - 1) bytes. This should be suitably
small for most use cases.
Sourcepub fn min_arena_capacity_max_error(&self) -> usize
pub fn min_arena_capacity_max_error(&self) -> usize
Returns the maximum error term for the minimum arena capacity calculation.