pub struct ArchiveValidator<'a> { /* private fields */ }Expand description
A validator that can verify archives with nonlocal memory.
Implementations
Sourceimpl<'a> ArchiveValidator<'a>
impl<'a> ArchiveValidator<'a>
Sourcepub fn with_max_depth(
bytes: &'a [u8],
max_subtree_depth: Option<NonZeroUsize>,
) -> Self
pub fn with_max_depth( bytes: &'a [u8], max_subtree_depth: Option<NonZeroUsize>, ) -> Self
Crates a new bounds validator for the given bytes with a maximum validation depth.