pub struct InlineAsBox;Expand description
A wrapper that serializes a reference as if it were boxed.
Unlike Inline, unsized references can be serialized with InlineAsBox.
References serialized with InlineAsBox cannot be deserialized because the
struct cannot own the deserialized value.
Example
use rkyv::{with::InlineAsBox, Archive};
#[derive(Archive)]
struct Example<'a> {
#[rkyv(with = InlineAsBox)]
a: &'a i32,
#[rkyv(with = InlineAsBox)]
b: &'a str,
}Trait Implementations
Sourceimpl<F: ArchiveUnsized + ?Sized> ArchiveWith<&F> for InlineAsBox
impl<F: ArchiveUnsized + ?Sized> ArchiveWith<&F> for InlineAsBox
Sourcetype Archived = ArchivedBox<<F as ArchiveUnsized>::Archived>
type Archived = ArchivedBox<<F as ArchiveUnsized>::Archived>
The archived type of
Self with F.Sourcetype Resolver = BoxResolver
type Resolver = BoxResolver
The resolver of a
Self with F.Sourceimpl Debug for InlineAsBox
impl Debug for InlineAsBox
Sourceimpl<F, S> SerializeWith<&F, S> for InlineAsBox
impl<F, S> SerializeWith<&F, S> for InlineAsBox