pub struct Lock;Expand description
A wrapper that locks a lock and serializes the value immutably.
This wrapper can panic under very specific circumstances when:
serialize_withis called and succeeds in locking the value to serialize it.- Another thread locks the value and panics, poisoning the lock
resolve_withis called and gets a poisoned value.
Unfortunately, it’s not possible to work around this issue internally. Users must ensure this doesn’t happen on their own through manual synchronization or guaranteeing that panics do not occur while holding locks.
Example
use std::sync::Mutex;
use rkyv::{with::Lock, Archive};
#[derive(Archive)]
struct Example {
#[rkyv(with = Lock)]
a: Mutex<i32>,
}Trait Implementations
Sourceimpl<F, T, D> DeserializeWith<F, Mutex<T>, D> for Lock
impl<F, T, D> DeserializeWith<F, Mutex<T>, D> for Lock
Sourceimpl<F, T, D> DeserializeWith<F, RwLock<T>, D> for Lock
impl<F, T, D> DeserializeWith<F, RwLock<T>, D> for Lock
Sourceimpl<F, S> SerializeWith<Mutex<F>, S> for Lock
impl<F, S> SerializeWith<Mutex<F>, S> for Lock