pub struct Map<T> { /* private fields */ }Expand description
A wrapper that applies another wrapper to the values contained in a type. This can be applied to a vector to map each element, or an option to map any contained value.
See ArchiveWith for more details.
Example
use rkyv::{
with::{InlineAsBox, Map},
Archive,
};
#[derive(Archive)]
struct Example<'a> {
// This will apply `InlineAsBox` to the `&i32` contained in this option
#[rkyv(with = Map<InlineAsBox>)]
option: Option<&'a i32>,
// This will apply `InlineAsBox` to each `&i32` contained in this vector
#[rkyv(with = Map<InlineAsBox>)]
vec: Vec<&'a i32>,
}Trait Implementations
Sourceimpl<A, O, const N: usize> ArchiveWith<[O; N]> for Map<A>where
A: ArchiveWith<O>,
impl<A, O, const N: usize> ArchiveWith<[O; N]> for Map<A>where
A: ArchiveWith<O>,
Sourceimpl<A, O> ArchiveWith<Option<O>> for Map<A>where
A: ArchiveWith<O>,
impl<A, O> ArchiveWith<Option<O>> for Map<A>where
A: ArchiveWith<O>,
Sourcetype Archived = ArchivedOption<<A as ArchiveWith<O>>::Archived>
type Archived = ArchivedOption<<A as ArchiveWith<O>>::Archived>
The archived type of
Self with F.Sourceimpl<A, O> ArchiveWith<Vec<O>> for Map<A>where
A: ArchiveWith<O>,
impl<A, O> ArchiveWith<Vec<O>> for Map<A>where
A: ArchiveWith<O>,
Sourcetype Archived = ArchivedVec<<A as ArchiveWith<O>>::Archived>
type Archived = ArchivedVec<<A as ArchiveWith<O>>::Archived>
The archived type of
Self with F.Sourcetype Resolver = VecResolver
type Resolver = VecResolver
The resolver of a
Self with F.Sourceimpl<O, A, D, const N: usize> DeserializeWith<[<A as ArchiveWith<O>>::Archived; N], [O; N], D> for Map<A>
impl<O, A, D, const N: usize> DeserializeWith<[<A as ArchiveWith<O>>::Archived; N], [O; N], D> for Map<A>
Sourceimpl<A, O, D> DeserializeWith<ArchivedOption<<A as ArchiveWith<O>>::Archived>, Option<O>, D> for Map<A>where
D: Fallible + ?Sized,
A: ArchiveWith<O> + DeserializeWith<<A as ArchiveWith<O>>::Archived, O, D>,
impl<A, O, D> DeserializeWith<ArchivedOption<<A as ArchiveWith<O>>::Archived>, Option<O>, D> for Map<A>where
D: Fallible + ?Sized,
A: ArchiveWith<O> + DeserializeWith<<A as ArchiveWith<O>>::Archived, O, D>,
Sourcefn deserialize_with(
field: &ArchivedOption<<A as ArchiveWith<O>>::Archived>,
d: &mut D,
) -> Result<Option<O>, D::Error>
fn deserialize_with( field: &ArchivedOption<<A as ArchiveWith<O>>::Archived>, d: &mut D, ) -> Result<Option<O>, D::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<A, O, D> DeserializeWith<ArchivedVec<<A as ArchiveWith<O>>::Archived>, Vec<O>, D> for Map<A>where
A: ArchiveWith<O> + DeserializeWith<<A as ArchiveWith<O>>::Archived, O, D>,
D: Fallible + ?Sized,
impl<A, O, D> DeserializeWith<ArchivedVec<<A as ArchiveWith<O>>::Archived>, Vec<O>, D> for Map<A>where
A: ArchiveWith<O> + DeserializeWith<<A as ArchiveWith<O>>::Archived, O, D>,
D: Fallible + ?Sized,
Sourcefn deserialize_with(
field: &ArchivedVec<<A as ArchiveWith<O>>::Archived>,
d: &mut D,
) -> Result<Vec<O>, D::Error>
fn deserialize_with( field: &ArchivedVec<<A as ArchiveWith<O>>::Archived>, d: &mut D, ) -> Result<Vec<O>, D::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<A, O, S> SerializeWith<Option<O>, S> for Map<A>
impl<A, O, S> SerializeWith<Option<O>, S> for Map<A>
Sourceimpl<A, O, S> SerializeWith<Vec<O>, S> for Map<A>
impl<A, O, S> SerializeWith<Vec<O>, S> for Map<A>