pub struct MapKV<K, V> { /* private fields */ }Expand description
A wrapper that applies key and value wrappers to the key-value pairs contained in a type. This can be applied to a hash map or B-tree map to map the key-value pairs.
Example
use std::collections::HashMap;
use rkyv::{
with::{Inline, InlineAsBox, MapKV},
Archive,
};
#[derive(Archive)]
struct Example<'a> {
// This will apply `InlineAsBox` to the `&str` key, and `Inline` to the
// `&str` value.
#[rkyv(with = MapKV<InlineAsBox, Inline>)]
hash_map: HashMap<&'a str, &'a str>,
}Trait Implementations
Sourceimpl<A, B, K, V> ArchiveWith<BTreeMap<K, V>> for MapKV<A, B>where
A: ArchiveWith<K>,
B: ArchiveWith<V>,
impl<A, B, K, V> ArchiveWith<BTreeMap<K, V>> for MapKV<A, B>where
A: ArchiveWith<K>,
B: ArchiveWith<V>,
Sourcetype Archived = ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>
type Archived = ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>
The archived type of
Self with F.Sourcetype Resolver = BTreeMapResolver
type Resolver = BTreeMapResolver
The resolver of a
Self with F.Sourceimpl<A, B, K, V, H> ArchiveWith<HashMap<K, V, H>> for MapKV<A, B>
impl<A, B, K, V, H> ArchiveWith<HashMap<K, V, H>> for MapKV<A, B>
Sourcetype Archived = ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>
type Archived = ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>
The archived type of
Self with F.Sourcetype Resolver = HashMapResolver
type Resolver = HashMapResolver
The resolver of a
Self with F.Sourceimpl<A, B, K, V, D> DeserializeWith<ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, BTreeMap<K, V>, D> for MapKV<A, B>where
A: ArchiveWith<K> + DeserializeWith<<A as ArchiveWith<K>>::Archived, K, D>,
B: ArchiveWith<V> + DeserializeWith<<B as ArchiveWith<V>>::Archived, V, D>,
K: Ord,
D: Fallible + ?Sized,
impl<A, B, K, V, D> DeserializeWith<ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, BTreeMap<K, V>, D> for MapKV<A, B>where
A: ArchiveWith<K> + DeserializeWith<<A as ArchiveWith<K>>::Archived, K, D>,
B: ArchiveWith<V> + DeserializeWith<<B as ArchiveWith<V>>::Archived, V, D>,
K: Ord,
D: Fallible + ?Sized,
Sourcefn deserialize_with(
field: &ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>,
deserializer: &mut D,
) -> Result<BTreeMap<K, V>, <D as Fallible>::Error>
fn deserialize_with( field: &ArchivedBTreeMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, deserializer: &mut D, ) -> Result<BTreeMap<K, V>, <D as Fallible>::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<A, B, K, V, D, S> DeserializeWith<ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, HashMap<K, V, S>, D> for MapKV<A, B>where
A: ArchiveWith<K> + DeserializeWith<<A as ArchiveWith<K>>::Archived, K, D>,
B: ArchiveWith<V> + DeserializeWith<<B as ArchiveWith<V>>::Archived, V, D>,
K: Hash + Eq,
D: Fallible + ?Sized,
S: Default + BuildHasher,
impl<A, B, K, V, D, S> DeserializeWith<ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, HashMap<K, V, S>, D> for MapKV<A, B>where
A: ArchiveWith<K> + DeserializeWith<<A as ArchiveWith<K>>::Archived, K, D>,
B: ArchiveWith<V> + DeserializeWith<<B as ArchiveWith<V>>::Archived, V, D>,
K: Hash + Eq,
D: Fallible + ?Sized,
S: Default + BuildHasher,
Sourcefn deserialize_with(
field: &ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>,
deserializer: &mut D,
) -> Result<HashMap<K, V, S>, <D as Fallible>::Error>
fn deserialize_with( field: &ArchivedHashMap<<A as ArchiveWith<K>>::Archived, <B as ArchiveWith<V>>::Archived>, deserializer: &mut D, ) -> Result<HashMap<K, V, S>, <D as Fallible>::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<A, B, K, V, S> SerializeWith<BTreeMap<K, V>, S> for MapKV<A, B>where
A: ArchiveWith<K> + SerializeWith<K, S>,
B: ArchiveWith<V> + SerializeWith<V, S>,
<A as ArchiveWith<K>>::Archived: Ord,
S: Fallible + Allocator + Writer + ?Sized,
S::Error: Source,
impl<A, B, K, V, S> SerializeWith<BTreeMap<K, V>, S> for MapKV<A, B>where
A: ArchiveWith<K> + SerializeWith<K, S>,
B: ArchiveWith<V> + SerializeWith<V, S>,
<A as ArchiveWith<K>>::Archived: Ord,
S: Fallible + Allocator + Writer + ?Sized,
S::Error: Source,
Sourceimpl<A, B, K, V, S, H> SerializeWith<HashMap<K, V, H>, S> for MapKV<A, B>where
A: ArchiveWith<K> + SerializeWith<K, S>,
B: ArchiveWith<V> + SerializeWith<V, S>,
K: Hash + Eq,
<A as ArchiveWith<K>>::Archived: Eq + Hash,
S: Fallible + Allocator + Writer + ?Sized,
S::Error: Source,
H: Default + BuildHasher,
H::Hasher: Default,
impl<A, B, K, V, S, H> SerializeWith<HashMap<K, V, H>, S> for MapKV<A, B>where
A: ArchiveWith<K> + SerializeWith<K, S>,
B: ArchiveWith<V> + SerializeWith<V, S>,
K: Hash + Eq,
<A as ArchiveWith<K>>::Archived: Eq + Hash,
S: Fallible + Allocator + Writer + ?Sized,
S::Error: Source,
H: Default + BuildHasher,
H::Hasher: Default,