pub struct NicheInto<N: ?Sized>(/* private fields */);Expand description
A wrapper that niches based on a generic Niching.
A common type combination is Option<Box<T>>. By niching None into the
null pointer, the archived version can save some space on-disk.
Example
use core::mem::size_of;
use rkyv::{
niche::niching::{NaN, Null},
with::NicheInto,
Archive, Archived,
};
#[derive(Archive)]
struct BasicExample {
maybe_box: Option<Box<str>>,
maybe_non_nan: Option<f32>,
}
#[derive(Archive)]
struct NichedExample {
#[rkyv(with = NicheInto<Null>)]
maybe_box: Option<Box<str>>,
#[rkyv(with = NicheInto<NaN>)]
maybe_non_nan: Option<f32>,
}
assert!(
size_of::<Archived<BasicExample>>()
> size_of::<Archived<NichedExample>>()
);Trait Implementations
Sourceimpl<T, N> ArchiveWith<Option<T>> for NicheInto<N>
impl<T, N> ArchiveWith<Option<T>> for NicheInto<N>
Sourceimpl<T, N, D> DeserializeWith<NichedOption<<T as Archive>::Archived, N>, Option<T>, D> for NicheInto<N>
impl<T, N, D> DeserializeWith<NichedOption<<T as Archive>::Archived, N>, Option<T>, D> for NicheInto<N>
Sourcefn deserialize_with(
field: &NichedOption<T::Archived, N>,
deserializer: &mut D,
) -> Result<Option<T>, D::Error>
fn deserialize_with( field: &NichedOption<T::Archived, N>, deserializer: &mut D, ) -> Result<Option<T>, D::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<T, N, S> SerializeWith<Option<T>, S> for NicheInto<N>
impl<T, N, S> SerializeWith<Option<T>, S> for NicheInto<N>