pub struct Unsafe;Expand description
A wrapper that allows serialize-unsafe types to be serialized.
Types like Cell and UnsafeCell may contain serializable types, but have
unsafe access semantics due to interior mutability. They may be safe to
serialize, but only under conditions that rkyv is unable to guarantee.
This wrapper enables serializing these types, and places the burden of verifying that their access semantics are used safely on the user.
Safety
Using this wrapper on types with interior mutability can create races conditions or allow access to data in an invalid state if access semantics are not followed properly. During serialization, the data must not be modified.
Example
use core::cell::{Cell, UnsafeCell};
use rkyv::{with::Unsafe, Archive};
#[derive(Archive)]
struct Example {
#[rkyv(with = Unsafe)]
cell: Cell<String>,
#[rkyv(with = Unsafe)]
unsafe_cell: UnsafeCell<String>,
}Trait Implementations
Sourceimpl<F: Archive> ArchiveWith<UnsafeCell<F>> for Unsafe
impl<F: Archive> ArchiveWith<UnsafeCell<F>> for Unsafe
Sourcefn resolve_with(
field: &UnsafeCell<F>,
resolver: Self::Resolver,
out: Place<Self::Archived>,
)
fn resolve_with( field: &UnsafeCell<F>, resolver: Self::Resolver, out: Place<Self::Archived>, )
Resolves the archived type using a reference to the field type
F.Sourceimpl<F, D> DeserializeWith<<F as Archive>::Archived, UnsafeCell<F>, D> for Unsafe
impl<F, D> DeserializeWith<<F as Archive>::Archived, UnsafeCell<F>, D> for Unsafe
Sourcefn deserialize_with(
field: &F::Archived,
deserializer: &mut D,
) -> Result<UnsafeCell<F>, D::Error>
fn deserialize_with( field: &F::Archived, deserializer: &mut D, ) -> Result<UnsafeCell<F>, D::Error>
Deserializes the field type
F using the given deserializer.Sourceimpl<F, S> SerializeWith<Cell<F>, S> for Unsafe
impl<F, S> SerializeWith<Cell<F>, S> for Unsafe
Sourceimpl<F, S> SerializeWith<UnsafeCell<F>, S> for Unsafe
impl<F, S> SerializeWith<UnsafeCell<F>, S> for Unsafe
Sourcefn serialize_with(
field: &UnsafeCell<F>,
serializer: &mut S,
) -> Result<Self::Resolver, S::Error>
fn serialize_with( field: &UnsafeCell<F>, serializer: &mut S, ) -> Result<Self::Resolver, S::Error>
Serializes the field type
F using the given serializer.Auto Trait Implementations
impl Freeze for Unsafe
impl RefUnwindSafe for Unsafe
impl Send for Unsafe
impl Sync for Unsafe
impl Unpin for Unsafe
impl UnsafeUnpin for Unsafe
impl UnwindSafe for Unsafe